==> haskell-tdigest-0.3.1-5-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tdigest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tdigest
version:              0.3.1
visibility:           public
id:                   tdigest-0.3.1-94GXMzzCL727CWFGDjf51t
key:                  tdigest-0.3.1-94GXMzzCL727CWFGDjf51t
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/haskell-tdigest#readme
synopsis:             On-line accumulation of rank-based statistics
description:
    A new data structure for accurate on-line accumulation of rank-based statistics such as quantiles and trimmed means.

    See original paper: "Computing extremely accurate quantiles using t-digest" by Ted Dunning and Otmar Ertl
    for more details <https://github.com/tdunning/t-digest/blob/07b8f2ca2be8d0a9f04df2feadad5ddc1bb73c88/docs/t-digest-paper/histo.pdf>.

category:             Numeric
abi:                  c1e2f43de2ebe124c5a5a7dd507f7d29
exposed:              True
exposed-modules:
    Data.TDigest Data.TDigest.Internal Data.TDigest.NonEmpty
    Data.TDigest.Postprocess Data.TDigest.Postprocess.Internal
    Data.TDigest.Tree Data.TDigest.Tree.Internal
    Data.TDigest.Tree.NonEmpty Data.TDigest.Tree.Postprocess
    Data.TDigest.Vector Data.TDigest.Vector.Internal
    Data.TDigest.Vector.NonEmpty Data.TDigest.Vector.Postprocess

import-dirs:          /usr/lib/ghc-9.2.8/site-local/tdigest-0.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tdigest-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tdigest
hs-libraries:         HStdigest-0.3.1-94GXMzzCL727CWFGDjf51t
depends:
    base-4.16.4.0 binary-0.8.9.0 deepseq-1.4.6.1
    foldable1-classes-compat-0.1-58GJLqoLEbIGoZMpmdl4cx
    reducers-3.12.4-3bvLbXEGLHS9FRcy0cG2cv transformers-0.5.6.2
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r
    vector-algorithms-0.9.0.2-DinaOLJn9F3JWEEZxX4tUv

haddock-interfaces:   /usr/share/doc/haskell-tdigest/html/tdigest.haddock
haddock-html:         /usr/share/doc/haskell-tdigest/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tdigest-0.3.1-54.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tdigest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tdigest
version:              0.3.1
visibility:           public
id:                   tdigest-0.3.1-AH47WFFbMtjLOxennAy8Ob
key:                  tdigest-0.3.1-AH47WFFbMtjLOxennAy8Ob
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/haskell-tdigest#readme
synopsis:             On-line accumulation of rank-based statistics
description:
    A new data structure for accurate on-line accumulation of rank-based statistics such as quantiles and trimmed means.

    See original paper: "Computing extremely accurate quantiles using t-digest" by Ted Dunning and Otmar Ertl
    for more details <https://github.com/tdunning/t-digest/blob/07b8f2ca2be8d0a9f04df2feadad5ddc1bb73c88/docs/t-digest-paper/histo.pdf>.

category:             Numeric
abi:                  a490d3d34b2773cf93855428f94872dc
exposed:              True
exposed-modules:
    Data.TDigest Data.TDigest.Internal Data.TDigest.NonEmpty
    Data.TDigest.Postprocess Data.TDigest.Postprocess.Internal
    Data.TDigest.Tree Data.TDigest.Tree.Internal
    Data.TDigest.Tree.NonEmpty Data.TDigest.Tree.Postprocess
    Data.TDigest.Vector Data.TDigest.Vector.Internal
    Data.TDigest.Vector.NonEmpty Data.TDigest.Vector.Postprocess

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tdigest-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tdigest-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tdigest-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tdigest
hs-libraries:         HStdigest-0.3.1-AH47WFFbMtjLOxennAy8Ob
depends:
    base-4.17.2.1 binary-0.8.9.1 deepseq-1.4.8.0
    foldable1-classes-compat-0.1-L4rpDxwiBvpA1HuXiW4dLF
    reducers-3.12.5-tcjIUxFMSIBxMAV7okNdy transformers-0.5.6.2
    vector-0.13.2.0-H3MTIE0bxkOEYwCD854O16
    vector-algorithms-0.9.1.0-1LdtmRdbL1ZLoCI2Ah0hdm

haddock-interfaces:   /usr/share/doc/haskell-tdigest/html/tdigest.haddock
haddock-html:         /usr/share/doc/haskell-tdigest/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
